# backend.ai-app
Ready-to-use Backend.AI app code for desktop / web. 

## Ready-to-use code repository

This repository is intended to provide console code to be ready to use without any prior work. The code requires a complicated compilation path to use it. This repository simplifies the process, providing already prepared code.

